@@ -134,13 +134,10 @@ static void changed_part_combo(GtkWidget *widget, gpointer data){
                          -1);
       selected_word->part = PLACE;
     }else if(strcmp(text,UTF8_KEIYOUSHI) == 0){
-      g_printf("Debug1\n");
       gtk_list_store_set(wordlist, &iter,
-                         COL_PART, UTF8_KEIYOUSHI
+                         COL_PART, UTF8_KEIYOUSHI,
                          -1);
-      g_printf("Debug2\n");      
       selected_word->part = ADJECTIVE;
-      g_printf("Debug3\n");      
     }
     
     free(text);
